API Services
========================================

`pyterrier-services <https://github.com/seanmacavaney/pyterrier-services>`__ provides PyTerrier
transformers for various API services.

.. code-block:: console
	:caption: Install ``pyterrier-services`` with pip

	pip install pyterrier-services


.. toctree::
   :maxdepth: 1

   dblp
   google
   pinecone
   semantic-scholar
